# Installation

Jupyter-forward can be installed from PyPI with pip:

```bash
python -m pip install jupyter-forward
```

Jupyter-forward is also available from conda-forge for conda installations:

```bash
conda install -c conda-forge jupyter-forward
```
